﻿namespace UltraGridChildBandSummary
{
    using System;
    using System.Data;
    using System.Windows.Forms;

    using Infragistics.Win.UltraWinGrid;

    public partial class Form1 : Form
    {
        private int rows = 20;
        private Random random = new Random();

        public Form1()
        {
            this.InitializeComponent();
            this.ultraGrid1.InitializeLayout += this.UltraGrid1_InitializeLayout;
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.ultraGrid1.DataSource = this.GetData(this.rows);

            this.ultraGrid1.DisplayLayout.ViewStyleBand = ViewStyleBand.OutlookGroupBy;
            this.ultraGrid1.DisplayLayout.Bands[0].SortedColumns.Add("Date", false, true);
            this.ultraGrid1.DisplayLayout.Bands[0].SortedColumns.Add("Id", false, true);
            this.ultraGrid1.Rows.ExpandAll(true);

            this.ultraCalcManager1.DeferredCalculationsEnabled = true;
        }

        private void UltraGrid1_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            e.Layout.Bands[0].Columns["Total"].Formula = "[Price] * [Amount]";
            e.Layout.Bands[0].Summaries.Add(SummaryType.Sum, this.ultraGrid1.DisplayLayout.Bands[0].Columns["Total"]);
        }

        private DataSet GetData(int rows)
        {
            DataSet ds = new DataSet();
            DataTable dt = ds.Tables.Add();

            dt.Columns.Add("Date", typeof(DateTime));
            dt.Columns.Add("Id", typeof(int));
            dt.Columns.Add("Amount", typeof(int));
            dt.Columns.Add("Price", typeof(double));
            dt.Columns.Add("Total", typeof(double));

            for (int row = 0; row < rows; row++)
            {
                DateTime date = DateTime.Today.AddDays(row % 3);
                int id = this.random.Next(0, 4);
                int amount = this.random.Next(10, 20);
                double price = this.random.Next(0, 1000) / 100.0;
                dt.Rows.Add(new object[] { date, id, amount, price, 0 });
            }

            return ds;
        }

        private void UltraButtonAmounts_Click(object sender, EventArgs e)
        {
            foreach (UltraGridRow topLevelRow in this.ultraGrid1.Rows)
            {
                foreach (UltraGridRow midLevelRow in ((UltraGridGroupByRow)topLevelRow).Rows)
                {
                    foreach (UltraGridRow row in ((UltraGridGroupByRow)midLevelRow).Rows)
                    {
                        row.Cells["Amount"].Value = (int)row.Cells["Amount"].Value + 10;
                    }
                }
            }
        }
    }
}
